.. image:: _static/logo.png
        :alt: AS3 Ninja

.. image:: https://github.com/simonkowallik/as3ninja/actions/workflows/ci-pipeline.yaml/badge.svg)](https://github.com/simonkowallik/as3ninja/actions/workflows/ci-pipeline.yaml
   :target: https://github.com/simonkowallik/as3ninja/actions
   :alt: CI Build Status
.. image:: https://readthedocs.org/projects/as3ninja/badge/?version=latest&style=flat
   :target: https://as3ninja.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status
.. image:: https://api.codeclimate.com/v1/badges/9f516ff8bde00c7c082d/maintainability
   :target: https://codeclimate.com/github/simonkowallik/as3ninja/maintainability
   :alt: Maintainability
.. image:: https://api.codeclimate.com/v1/badges/9f516ff8bde00c7c082d/test_coverage
   :target: https://codeclimate.com/github/simonkowallik/as3ninja/test_coverage
   :alt: Test Coverage
